.. _ref-installation:

============
Installation
============

Either check out Metrology from `GitHub <http://github.com/cyberdelia/metrology>`_ or to pull a release off `PyPI <http://pypi.python.org/pypi/metrology>`_ ::

       pip install metrology
